pub struct MigrateConfig {
pub dir: String,
pub database_url: Option<String>,
pub auto_regenerate: bool,
}Fields
dir: Stringdatabase_url: Option<String>auto_regenerate: boolTrait Implementations
Sourceimpl Clone for MigrateConfig
impl Clone for MigrateConfig
Sourcefn clone(&self) -> MigrateConfig
fn clone(&self) -> MigrateConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MigrateConfig
impl Debug for MigrateConfig
Sourceimpl<'de> Deserialize<'de> for MigrateConfig
impl<'de> Deserialize<'de> for MigrateConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MigrateConfig
impl JsonSchema for MigrateConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MigrateConfig
impl RefUnwindSafe for MigrateConfig
impl Send for MigrateConfig
impl Sync for MigrateConfig
impl Unpin for MigrateConfig
impl UnsafeUnpin for MigrateConfig
impl UnwindSafe for MigrateConfig