pub struct SqlcxConfig {
pub sql: String,
pub parser: String,
pub targets: Vec<TargetConfig>,
pub overrides: HashMap<String, String>,
pub migrate: Option<MigrateConfig>,
}Fields
sql: Stringparser: Stringtargets: Vec<TargetConfig>overrides: HashMap<String, String>migrate: Option<MigrateConfig>Trait Implementations
Sourceimpl Clone for SqlcxConfig
impl Clone for SqlcxConfig
Sourcefn clone(&self) -> SqlcxConfig
fn clone(&self) -> SqlcxConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SqlcxConfig
impl Debug for SqlcxConfig
Sourceimpl<'de> Deserialize<'de> for SqlcxConfig
impl<'de> Deserialize<'de> for SqlcxConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SqlcxConfig
impl JsonSchema for SqlcxConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SqlcxConfig
impl RefUnwindSafe for SqlcxConfig
impl Send for SqlcxConfig
impl Sync for SqlcxConfig
impl Unpin for SqlcxConfig
impl UnsafeUnpin for SqlcxConfig
impl UnwindSafe for SqlcxConfig