pub struct TargetConfig {
pub language: String,
pub out: String,
pub schema: String,
pub driver: String,
pub overrides: HashMap<String, String>,
}Fields
language: Stringout: Stringschema: Stringdriver: Stringoverrides: HashMap<String, String>Trait Implementations
Sourceimpl Clone for TargetConfig
impl Clone for TargetConfig
Sourcefn clone(&self) -> TargetConfig
fn clone(&self) -> TargetConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetConfig
impl Debug for TargetConfig
Sourceimpl<'de> Deserialize<'de> for TargetConfig
impl<'de> Deserialize<'de> for TargetConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TargetConfig
impl JsonSchema for TargetConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TargetConfig
impl RefUnwindSafe for TargetConfig
impl Send for TargetConfig
impl Sync for TargetConfig
impl Unpin for TargetConfig
impl UnsafeUnpin for TargetConfig
impl UnwindSafe for TargetConfig