Functions
- escape_
sql - Escape a SQL string for embedding as a Go string literal.
- func_
params - Generate the function signature params for a query.
- generate_
result_ struct - Generate a result struct for :execresult queries.
- generate_
row_ struct - Generate the row struct for queries that return non-table columns.
- query_
args - Generate the args list for ExecContext/QueryContext/Exec/Query calls.
- scan_
fields - Generate scan fields (&i.FieldName) for a row.